Channel

Enum Channel 

pub enum Channel {
Show 18 variants A, B, C, D, E, F, G, H, R, I, S, J, T, U, V, W, K, L,
}

Variants



A

410nm - AS72653



B

435nm - AS72653



C

460nm - AS72653



D

485nm - AS72653



E

510nm - AS72653



F

535nm - AS72653



G

560nm - AS72652



H

585nm - AS72652



R

610nm - AS72651



I

645nm - AS72652



S

680nm - AS72651



J

705nm - AS72652



T

730nm - AS72651



U

760nm - AS72651



V

810nm - AS72651



W

860nm - AS72651



K

900nm - AS72652



L

940nm - AS72652

Implementations

Source

impl Channel

pub fn get_device_for_channel(&self) -> Device

Each channel is only read from one of three sensors